#!/bin/sh
# Script that create a floppy image during the minix instalation process. 
# Good if you don't have a ready to use minix image or genarate the new one.
# 
# The bzipped tar with the system and sources:
# http://www.minix3.org/previous-versions/bzipped/Intel-2.0.4.tar.bz2
#
# To use this script, unpack the Intel-2.0.4.tar.bz2 in this directory
# and run it (./installdisks.sh)

# here you define a disk image.
VFLOPPY="./vfloppya.img"
PREFIX_MINIX="./Intel-2.0.4"                # path to original minix files.
#

FILES_NEED=( $PREFIX_MINIX/i386/ROOT.MNX 
             $PREFIX_MINIX/i386/NET.TAZ 
						 $PREFIX_MINIX/i386/USR.MNX 
						 $PREFIX_MINIX/i386/USR.TAZ 
						 $PREFIX_MINIX/src/FIX.TAZ 
						 $PREFIX_MINIX/src/SYS.TAZ 
						 $PREFIX_MINIX/src/CMD.TAZ )
for file in ${FILES_NEED[*]} ; do
  if [ -f $file ];then
    echo -n "";
  else
    echo " file  $file missed"
		echo "maybe be you need"
    exit 1
fi
done
TMPFILE=`mktemp  /tmp/minixinst.XXXXX`
dialog --menu  "Use install disk:" 25 32 12  \
1 "ROOT/USR" \
2 "USR 1" \
3 "USR 2" \
4 "USR 3" \
5 "NET tools" \
6 "System & kernel src 1" \
7 "System & kernel src 2" \
8 "Command src 1" \
9 "Command src 2" \
10 "Command src 3" \
11 "Fixed RTL8139 driver" \
--stderr 2> $TMPFILE && OPT=`cat $TMPFILE`
LAST_MSG="done."
case $OPT in
  1) echo "copying ROOT/USR to $VFLOPPY..."
	cat $PREFIX_MINIX/i386/ROOT.MNX $PREFIX_MINIX/i386/USR.MNX > $VFLOPPY
	;;
	2) echo "copying USR1 to $VFLOPPY..."
	dd if=$PREFIX_MINIX/i386/USR.TAZ of=$VFLOPPY bs=1440k count=1 skip=0
	;;
	3) echo "copying USR2 to $VFLOPPY..."
	dd if=$PREFIX_MINIX/i386/USR.TAZ of=$VFLOPPY bs=1440k count=1 skip=1
	;;
	4) echo "copying USR3 to $VFLOPPY..."
	dd if=$PREFIX_MINIX/i386/USR.TAZ of=$VFLOPPY bs=1440k count=1 skip=2
	;;
	5) echo "copying NET tools to $VFLOPPY..."
	dd if=$PREFIX_MINIX/i386/NET.TAZ of=$VFLOPPY 
	;;
	6) echo "copying system and kernel sources 1 to $VFLOPPY..."
	dd if=$PREFIX_MINIX/src/SYS.TAZ of=$VFLOPPY bs=1440k count=1 skip=0
	;;
	7) echo "copying system and kernel sources 2 to $VFLOPPY..."
	dd if=$PREFIX_MINIX/src/SYS.TAZ of=$VFLOPPY bs=1440k count=1 skip=1
	;;
	8) echo "copying command sources 1 to $VFLOPPY..."
	dd if=$PREFIX_MINIX/src/CMD.TAZ of=$VFLOPPY bs=1440k count=1 skip=0
	;;
	9) echo "copying command sources 2 to $VFLOPPY..."
	dd if=$PREFIX_MINIX/src/CMD.TAZ of=$VFLOPPY bs=1440k count=1 skip=1
	;;
	10) echo "copying command sources 3 to $VFLOPPY..."
	dd if=$PREFIX_MINIX/src/CMD.TAZ of=$VFLOPPY bs=1440k count=1 skip=2
	;;
	11) echo "copying Fixed RTL8139 driver to $VFLOPPY..."
	dd if=$PREFIX_MINIX/src/FIX.TAZ of=$VFLOPPY
	;;
	'') LAST_MSG=""
	;;
	*)
	echo "invalid option: $OPT" 
	;;
esac
RET=$?
rm $TMPFILE
if [ $RET != "0" ]; then
LAST_MSG="Error!"
fi
echo $LAST_MSG
exit $RET
